# -*- coding: utf-8 -*-
"""
Created on Tue Nov 15 15:47:29 2016

@author: doarni
"""

#Special Keyboard KeyID's
#------------------

#ESC
#------
esc = 27

#CTRL 
#------
lctrl = 162
rctrl = 163

#SHIFT
#------
lshift = 160
rshift = 161

#ALT
#------
lalt = 164
ralt = 165

#ENTER
#------
enter = 13

#TAB
#------
tab = 9

#tilde
#------
tilde = 192

#ARROW KEYS
#------
arrowleft = 37
arrowright = 39
arrowup = 38
arrowdown = 40

#HOME
#------
home = 36

#F Keys
#------
f1 = 112
f2 = 113
f3 = 114
f4 = 115
f5 = 116
f6 = 117
f7 = 118
f8= 119
f9 = 120
f10 = 121
f11 = 122
f12 = 123

#NUMPAD
#------
NUM_0 = 96
NUM_1 = 97
NUM_2 = 98
NUM_3 = 99
NUM_4 = 100
NUM_5 = 101
NUM_6 = 102
NUM_7 = 103
NUM_8 = 104
NUM_9 = 105
NUM_add = 107
NUM_subtract = 109
NUM_multiply = 106
NUM_divide = 111
NUM_decimalPoint = 110

#VK_KEYS
#------
VK_F1 = 'VK_F1'
VK_F2 = 'VK_F2'
VK_F3 = 'VK_F3'
VK_F4 = 'VK_F4'
VK_F5 = 'VK_F5'
VK_F6 = 'VK_F6'
VK_F7 = 'VK_F7'
VK_F8 = 'VK_F8'
VK_F9 = 'VK_F9'
VK_F10 = 'VK_F10'
VK_F11 = 'VK_F11'
VK_F12 = 'VK_F12'
VK_LCONTROL = 'VK_LCONTROL'
VK_LALT = 'VK_LMENU'
VK_LSHIFT = 'VK_LSHIFT'
VK_PGDOWN = 'VK_NEXT'
VK_PRINT = 'VK_PRINT'
VK_PGUP = 'VK_PRIOR'
VK_RCONTROL = 'VK_RCONTROL'
VK_RALT = 'VK_RMENU'
VK_RSHIFT = 'VK_RSHIFT'
VK_PRINTSCREEN = 'VK_SNAPSHOT'
VK_TAB = 'VK_TAB'
