upSaveButton = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > div > table > tbody > tr:nth-child(8) > td > table > tbody > tr > td:nth-child(2) > span > div > div.GLNOMTPDN4C.GLNOMTPDK4C'
upUser = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div > div > table > tbody > tr > td.GLNOMTPDLX > table > tbody > tr > td.GLNOMTPDIX > span'
upUserSettingsButton = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(3) > div > div:nth-child(2) > div > div > div > div > div.GLNOMTPDBGB > table > tbody > tr:nth-child(1) > td:nth-child(2) > table > tbody > tr > td.GLNOMTPDNFB > span'
