"""
Used to reference dll files

DO NOT DELETE THIS FILE
"""
import os

DLL_PATH = os.path.dirname(os.path.realpath(__file__))
PYTHON_EMBEDDINGTEST_DLL = "Python.EmbeddingTest.dll"
PYTHON_RUNTIME_DLL = "Python.Runtime.dll"
PYTHON_TEST_DLL = "Python.Test.dll"
SMS_DLL = "smsdll"


