prodChooserAddEvenBack = ') > td.GLNOMTPDHM.GLNOMTPDEO > div > table > tbody > tr > td > table > tbody > tr > td.GLNOMTPDBYI > span'
prodchooserSearchButton = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(2) > div > table > tbody > tr:nth-child(1) > td.GLNOMTPDAS  > span > div > div.GLNOMTPDJ3C.GLNOMTPDG3C'
prodChooserAddOddBack = ') > td.GLNOMTPDGM.GLNOMTPDEO > div > table > tbody > tr > td > table > tbody > tr > td.GLNOMTPDBYI > span'
prodchooserSearchBar = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(2) > div > table > tbody > tr:nth-child(1) > td.GLNOMTPDP-D > input'
prodChooserTableData = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div > table > tbody'
prodChooserDescBack = ') > td:nth-child(3) > div'
prodChooserAddLastBack = ') > td.GLNOMTPDGM.GLNOMTPDEO.GLNOMTPDMM > div > table > tbody > tr > td > table > tbody > tr > td.GLNOMTPDBYI > span'
prodChooserTRpathBack = ')'
prodChooserAddFront = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
prodchooserAdd = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div > table > tbody > tr > td.GLNOMTPDHM.GLNOMTPDEO.GLNOMTPDBP > div > table > tbody > tr > td > table > tbody > tr > td.GLNOMTPDBYI > span'
prodChooserAddLastFront = 'body > div.GLNOMTPDL-D> div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child( '
prodChooserTRpathFront = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
prodChooserResults = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(2) > div > table > tbody > tr > td > table > tbody > tr > td.GLNOMTPDBAE'
prodChooserDescFront = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(4) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div > table > tbody > tr:nth-child('
prodchooserFinishButton = 'body > div.GLNOMTPDL-D > div > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(4) > div > div:nth-child(3) > div > table > tbody > tr > td.GLNOMTPDD0D > span > div > div.GLNOMTPDJ3C.GLNOMTPDG3C'
prodchooserSelect = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(3) > div > div > div > div:nth-child(1) > div:nth-child(2) > div.GLNOMTPDCW > table > tbody > tr > td > table > tbody > tr > td:nth-child(2) > span'
