stMutateSavebutton = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(2) > td > table > tbody > tr > td:nth-child(2) > span > div > div.GLNOMTPDN4C.GLNOMTPDK4C'
stMutateAlert = 'body > div.gwt-PopupPanel > div > div > table > tbody > tr > td > div > table > tbody > tr > td > span > div > div.GLNOMTPDJ3C.GLNOMTPDG3C'
stnote = 'CI-ZDI Mutation, Loaners Late Debit Policy'
stMutateCancelButton = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(2) > td > table > tbody > tr > td.GLNOMTPDJYD > span > div > div.GLNOMTPDJ3C.GLNOMTPDG3C'
stMutateAllAvailable = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(1) > td > table > tbody > tr:nth-child(3) > td.GLNOMTPDDS > div > span > img'
stMutateQuantity = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(1) > td > table > tbody > tr:nth-child(2) > td.GLNOMTPDDS > input'
stMutateNote = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(1) > td > table > tbody > tr:nth-child(4) > td.GLNOMTPDDS > textarea'
stMutateError = 'body > div:nth-child(13) > div > div > table > tbody > tr > td > div > table > tbody > tr > td > span > div > div.GLNOMTPDJ3C.GLNOMTPDG3C'
stMutateButton = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(3) > div > div:nth-child(2) > div > div:nth-child(2) > div > table > tbody > tr > td:nth-child(7) > table > tbody > tr > td > span'
