from setuptools import setup

setup(name='pySMS',
        	version= '3.0.0',
    description='ZSMS Python Module',
    author='Ian Doarn',
    author_email='ian.doarn@zimmerbiomet.com',
    url='https://github.com/IanDoarn/pySMS',
    packages=['pySMS',
              'pySMS.utils',
              'pySMS.utils.logic',
              'pySMS.data',
              'pySMS.json',
              'pySMS.pgsql',
              'pySMS.pgsql.sql',
              'pySMS.excel',
              'pySMS.excel.ui',
              'pySMS.ui',
              'pySMS.req',
              'pySMS.html',
              'pySMS.html.pathdata',
              'pySMS.html.pathdata.json'],
    install_requires=['selenium>=3.0.2',
                      'lxml>=3.7.2',
                      'colorama>=0.3.7',
                      'prettytable>=0.7.2',
                      'cssselect>=1.0.1',
                      'pythonnet>=2.2.2'],
    package_data={'pySMS.html.pathdata.json': ['*.json'],
                  'pySMS.html': ['*.html'],
                  'pySMS.pgsql.sql': ['*.sql'],
                  'pySMS.data': ['*.json.gz', '*.gz'],
                  'pySMS.json': ['*.json'],
                  'pySMS': ['*.exe', '*.ini', '*.pyd', '*.dll', '*.xml']})