InventoryTab = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div > div > table > tbody > tr > td.GLNOMTPDKX > img:nth-child(2)'
CaseTab = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div > div > table > tbody > tr > td.GLNOMTPDKX > img:nth-child(1)'
checkSite = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(2) > div > div > div > table > tbody > tr > td.GLNOMTPDJX > table > tbody > tr > td.GLNOMTPDFX > span'
