adjMenuSaveButton = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(2) > td > table > tbody > tr > td:nth-child(2) > span > div > div.GLNOMTPDN4C.GLNOMTPDK4C'
adjAdjustButton = 'body > div:nth-child(8) > div:nth-child(2) > div > div:nth-child(2) > div > div:nth-child(6) > div > div:nth-child(2) > div > div:nth-child(3) > div > div:nth-child(5) > div > div:nth-child(2) > div > div:nth-child(2) > div > table > tbody > tr > td.GLNOMTPDNWG > table > tbody > tr > td.GLNOMTPDMWG > span'
adjMenuQuantity = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(1) > td > table > tbody > tr:nth-child(1) > td.GLNOMTPDDS > input'
adjMenuCancelButton = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(2) > td > table > tbody > tr > td.GLNOMTPDBYD > span > div > div.GLNOMTPDJ3C.GLNOMTPDG3C'
adjMenuNote = 'body > div.gwt-PopupPanel > div > div > div > table > tbody > tr > td > div > div.GLNOMTPDNBD > div > table > tbody > tr:nth-child(1) > td > table > tbody > tr:nth-child(2) > td.GLNOMTPDDS > textarea'
